// java wrapper for vtkDirectedAcyclicGraph object
//

package vtk;
import vtk.*;

public class vtkDirectedAcyclicGraph extends vtkDirectedGraph
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native long GetData_3(vtkInformation id0);
  public vtkDirectedAcyclicGraph GetData(vtkInformation id0) {
    long temp = GetData_3(id0);

    if (temp == 0) return null;
    return (vtkDirectedAcyclicGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_4(vtkInformationVector id0,int id1);
  public vtkDirectedAcyclicGraph GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_4(id0,id1);

    if (temp == 0) return null;
    return (vtkDirectedAcyclicGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkDirectedAcyclicGraph() { super(); }

  public vtkDirectedAcyclicGraph(long id) { super(id); }
  public native long   VTKInit();

}
